// Copyright (c) 2024 Zeni Kim <zenik@smarteching.com>
// Use of this source code is governed by MIT-style
// license that can be found in the LICENSE file.

package controllers

import (
	"fmt"
	"os"
	"strconv"

	"git.smarteching.com/goffee/core"
	"git.smarteching.com/goffee/core/template/components"
)

// Show home page
func Themedemo(c *core.Context) *core.Response {

	// check if template engine is enabled
	TemplateEnableStr := os.Getenv("TEMPLATE_ENABLE")
	if TemplateEnableStr == "" {
		TemplateEnableStr = "false"
	}
	TemplateEnable, _ := strconv.ParseBool(TemplateEnableStr)

	if TemplateEnable {

		// first, include all compoments
		type templateData struct {
			PageCard components.PageCard
		}

		// now fill data of the components
		tmplData := templateData{
			PageCard: components.PageCard{
				CardTitle: "Card title",
				CardBody:  "Loerm ipsum at deim",
			},
		}

		return c.Response.Template("custom_theme_base.html", tmplData)

	} else {

		message := "{\"message\": \"Error, template not enabled\"}"
		return c.Response.Json(message)

	}

}

// Show form element page
func Themeform(c *core.Context) *core.Response {

	// check if template engine is enabled
	TemplateEnableStr := os.Getenv("TEMPLATE_ENABLE")
	if TemplateEnableStr == "" {
		TemplateEnableStr = "false"
	}
	TemplateEnable, _ := strconv.ParseBool(TemplateEnableStr)

	if TemplateEnable {

		// first, include all compoments
		type templateData struct {
			FormText       components.FormInput
			FormEmail      components.FormInput
			FormButton     components.FormButton
			FormSelectCity components.FormSelect
			FormTextarea   components.FormTextarea
			FormRadio      components.FormRadio
			FormCheckbox   components.FormCheckbox
		}

		// for select options
		var allOptions []components.FormSelectOption
		var option components.FormSelectOption
		option.Value = "ch"
		option.Caption = "China"
		allOptions = append(allOptions, option)
		option.Value = "ba"
		option.Caption = "Buenos Aires"
		allOptions = append(allOptions, option)
		option.Value = "fr"
		option.Caption = "France"
		selectedOption := option
		allOptions = append(allOptions, option)

		// for radio options
		var allOptionsr []components.FormRadioItem
		var optionr components.FormRadioItem
		optionr.ID = "citysch"
		optionr.Name = "citys"
		optionr.Value = "china"
		optionr.Label = "China"
		allOptionsr = append(allOptionsr, optionr)
		optionr.ID = "citysba"
		optionr.Name = "citys"
		optionr.Value = "buenosaires"
		optionr.Label = "Buenos Aires"
		//optionr.IsDisabled = true
		allOptionsr = append(allOptionsr, optionr)

		// for radio options
		var allOptionsc []components.FormCheckboxItem
		var optionc components.FormCheckboxItem
		optionc.ID = "citysch"
		optionc.Name = "citys"
		optionc.Value = "china"
		optionc.Label = "China"
		allOptionsc = append(allOptionsc, optionc)
		optionc.ID = "citysba"
		optionc.Name = "citys"
		optionc.Value = "buenosaires"
		optionc.Label = "Buenos Aires"
		//optionc.IsChecked = true
		allOptionsc = append(allOptionsc, optionc)

		// now fill data of the components
		tmplData := templateData{
			FormText: components.FormInput{
				ID:          "text",
				Label:       "Name",
				Type:        "text",
				Hint:        "This is sample hint",
				Placeholder: "Enter your name",
			},
			FormEmail: components.FormInput{
				ID:          "email",
				Label:       "Email",
				Type:        "email",
				Placeholder: "Enter your email address",
			},
			FormButton: components.FormButton{
				Text:      "Login",
				IsSubmit:  true,
				IsPrimary: true,
			},
			FormSelectCity: components.FormSelect{
				ID:             "city",
				Label:          "Select city",
				AllOptions:     allOptions,
				SelectedOption: selectedOption,
			},
			FormTextarea: components.FormTextarea{
				ID:    "text",
				Label: "Example textarea",
			},
			FormRadio: components.FormRadio{
				Label:     "Radio buttons",
				AllRadios: allOptionsr,
			},
			FormCheckbox: components.FormCheckbox{
				Label:       "Checkbox options",
				AllCheckbox: allOptionsc,
			},
		}
		return c.Response.Template("custom_theme_formpage.html", tmplData)

	} else {

		message := "{\"message\": \"Error, template not enabled\"}"
		return c.Response.Json(message)

	}

}

// Show form element page
func Themecontent(c *core.Context) *core.Response {

	// check if template engine is enabled
	TemplateEnableStr := os.Getenv("TEMPLATE_ENABLE")
	if TemplateEnableStr == "" {
		TemplateEnableStr = "false"
	}
	TemplateEnable, _ := strconv.ParseBool(TemplateEnableStr)

	if TemplateEnable {

		// first, include all compoments
		type templateData struct {
			ContentTable components.ContentTable
		}

		// TABLES
		// for th head
		var allTh []components.ContentTableTH
		var th components.ContentTableTH
		th.Value = "Column heading 1"
		allTh = append(allTh, th)
		th.Value = "Column heading 2"
		allTh = append(allTh, th)
		th.ID = "ba"
		th.Value = "Column heading 3"
		allTh = append(allTh, th)
		// for td items
		var allTd [][]components.ContentTableTD
		var vals []components.ContentTableTD
		// rows
		for i := 0; i < 5; i++ {
			for b := 0; b < len(allTh); b++ {
				vals[b].Value = fmt.Sprintf("%s%d%d", "TD data: ", b, i)
			}
			allTd = append(allTd, vals)
		}

		// now fill data of the components
		tmplData := templateData{
			ContentTable: components.ContentTable{
				ID:    "email",
				Label: "Email",
				AllTH: allTh,
				AllTD: allTd,
			},
		}
		return c.Response.Template("custom_theme_contentpage.html", tmplData)

	} else {

		message := "{\"message\": \"Error, template not enabled\"}"
		return c.Response.Json(message)

	}

}
